package prodotti_fornitori;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

class Fornitore {
    private String cf;
    private String nome;
    private String indirizzo;
    private String citta;
    private final List<Prodotto> prodotti = new ArrayList<>();

    public Fornitore() { }

    public Fornitore(String cf, String nome, String indirizzo, String citta) {
        this.cf = cf;
        this.nome = nome;
        this.indirizzo = indirizzo;
        this.citta = citta;
    }

    public String getCf() {
        return cf;
    }

    public void setCf(String cf) {
        this.cf = cf;
    }

    public String getNome() {
        return nome;
    }

    public void setNome(String nome) {
        this.nome = nome;
    }

    public String getIndirizzo() {
        return indirizzo;
    }

    public void setIndirizzo(String indirizzo) {
        this.indirizzo = indirizzo;
    }

    public String getCitta() {
        return citta;
    }

    public void setCitta(String citta) {
        this.citta = citta;
    }

    public void printFornitoreById(String id) {
        this.loadFornitoreById(id);
        System.out.println(this);
    }

    private void loadFornitoreById(String id) {
        String query = "SELECT F.\"Nome\", F.\"Indirizzo\", F.\"Città\", P.\"CP\", P.\"Nome\", P.\"Marca\", P.\"Modello\"" +
                "from \"prodotti_fornitori\".\"Prodotti\" P " +
                "JOIN \"prodotti_fornitori\".\"Catalogo\" C " +
                "ON (P.\"CP\" = C.\"P\")" +
                "JOIN \"prodotti_fornitori\".\"Fornitori\" F " +
                "ON (F.\"CF\" = C.\"F\")" +
                "WHERE \"CF\" = ?";

        PreparedStatement ps = null;
        ResultSet rs = null;

        try {
            ps = DbHandler.getInstance().getPreparedStatement(query);
            ps.setString(1,id);
            rs = ps.executeQuery();

            if(rs.next()) {
                this.setCf(id);
                this.setNome(rs.getString(1));
                this.setIndirizzo(rs.getString(2));
                this.setCitta(rs.getString(3));

                Prodotto p;

                do {
                    p = new Prodotto(rs.getString(4),rs.getString(5),rs.getString(6),rs.getString(7));
                    this.prodotti.add(p);
                } while (rs.next());
            }

        } catch (SQLException e) {
            e.printStackTrace();
        } finally {
            try {
                if (rs!=null)
                    rs.close();
            } catch (SQLException e) {
                e.printStackTrace();
            }
            try {
                if(ps!=null)
                    ps.close();
            } catch (SQLException e) {
                e.printStackTrace();
            }
            try {
                DbHandler.getInstance().closeConnection();
            } catch (SQLException e) {
                e.printStackTrace();
            }
        }
    }

    public String toString() {
        StringBuffer sb = new StringBuffer();
        prodotti.forEach(x -> sb.append(x.toString()).append("\n"));
        return sb.toString();
    }
}